@@ -39,7 +39,7 @@ my @inbound;
 my @outbound_bck;
 my @outbound;
 my ( @line2find, @replacement );
-my $max_num_files = 4;
+my $max_num_files = 5;
 
 my $up3dirs = '/../../..';
 my $up4dirs = '/../../../..';
@@ -50,8 +50,8 @@ and file
 =cut
 
 my $local       = getcwd();
-my $old_version = '0.82.8';
-my $new_version = '0.82.9';
+my $old_version = '0.83.0';
+my $new_version = '0.84.0';
 
 my $i = 0;
 $line2find[$i]   = ("L_SUV$old_version.pl");
@@ -87,6 +87,14 @@ $replacement[$i] = "VERSION = '$new_version';";
 $file[$i]      = 'SeismicUnixGui.pm';
 $path2file[$i] = $local . $up4dirs;
 
+$i = 4;
+$line2find[$i]     = "'SeismicUnixGuiInstallationGuide0.83.0.pdf';";
+print("line2find   = $line2find[$i]\n");
+$replacement[$i] = "'SeismicUnixGuiInstallationGuide$new_version.pdf';";
+print("replacement = $replacement[$i]\n");
+$file[$i]         = 'help_button_messages.pm';
+$path2file[$i]    = $local . $up3dirs . '/messages';
+
 =head2 Set files and paths
 
 =cut
