@@ -307,7 +307,7 @@ my $var = {
 	_base_file_name         => 'base_file_name',
 	_clear_text             => '',
 	_color_default          => 'grey',           # first color listbox to select
-	_config_file_format     => '%-35s%1s%-20s',
+	_config_file_format     => '                                                        ',
 	_eight_characters       => '8',
 	_empty_string           => '',
 	_failure                => -1,
@@ -344,7 +344,7 @@ my $var = {
 	_main_window_geometry          => '1100x750+12+5',
 	_medium_width                  => '100',
 	_message_box_geometry          => '400x250+400+400',
-	_min_clicks4save_button        => 19,     # fixing leaky param_widget memory
+	_min_clicks4save_button        => 45,     # B4:19; fixing leaky param_widget memory
 	_min_clicks4flow_select        => 8,      # fixing leaky param_widget memory
 	_ms2s                          => 0.001,
 	_my_arial                      => "-*-arial-normal-r-*-*-*-120-*-*-*-*-*-*",
@@ -371,7 +371,7 @@ my $var = {
 	_one_character                 => '1',
 	_one_pixel                     => '1',
 	_one_pixel_borderwidth         => '1',
-	_program_title                 => 'SeismicUnixGui V0.82.9',
+	_program_title                 => 'SeismicUnixGui V0.84.0',
 	_project_selector_title        => 'Project Selector',
 	_l_suplot_title                => 'L_suplot',
 	_project_selector_title        => 'Project Selector',
